@@ -594,8 +594,11 @@ my lovely bytes
             )
         )
 
-        form = cgi.parse_multipart(BytesIO(output), {"boundary": b"heyDavid"})
-        self.assertEqual(set([b'just a string\r\n', b'another string']),
+        form = cgi.parse_multipart(BytesIO(output), {
+            "boundary": b"heyDavid",
+            "CONTENT-LENGTH": str(len(output)),
+        })
+        self.assertEqual(set(['just a string\r\n', 'another string']),
                          set(form['cfield']))
 
         self.assertEqual(set([b'my lovely bytes2']), set(form['efield']))
